function [x, t] = BasicScriptPK(drug, bw, Simtime)
%clear workspace
%close all;
%clear all;

%% Definition of initial concentration & volumes & mol. mass & simulation time

NrTissue = 14;
% Volumes of each tissue
V = zeros(NrTissue,1);
V(1)  = 0.076;  % Volume (Vt) of rat-Adipose
V(2)  = 0.04148;% Volume (Vt) of rat-Bone
V(3)  = 0.0057; % Volume (Vt) of rat-Brain
V(4)  = 0.027;  % Volume (Vt) of rat-Gut
V(5)  = 0.0033; % Volume (Vt) of rat-Heart
V(6)  = 0.0073; % Volume (Vt) of rat-Kidney
V(7)  = 0.0366; % Volume (Vt) of rat-Liver
V(8)  = 0.005;  % Volume (Vt) of rat-Lung
V(9)  = 0.404;  % Volume (Vt) of rat-Muscle
V(10) = 0.19;   % Volume (Vt) of rat-Skin
V(11) = 0.002;  % Volume (Vt) of rat-Spleen
V(12) = 0.0272; % Volume (Vt) of rat-Arterial blood
V(13) = 0.0544; % Volume (Vt) of rat-Venous blood
V(14) = 1;      % Volume (Vt) of rat-sink
V     = V.*bw;

Q = zeros(NrTissue,1);
Q(1)  = 0.07;   % Blood Flow Rates [L/min] of rat-Adipose
Q(2)  = 0.122;  % Blood Flow Rates [L/min] of rat-Bone
Q(3)  = 0.02;   % Blood Flow Rates [L/min] of rat-Brain
Q(4)  = 0.131;  % Blood Flow Rates [L/min] of rat-Gut
Q(5)  = 0.049;  % Blood Flow Rates [L/min] of rat-Heart
Q(6)  = 0.141;  % Blood Flow Rates [L/min] of rat-Kidney
Q(7)  = 0.175;  % Blood Flow Rates [L/min] of rat-Liver
Q(8)  = 1;      % Blood Flow Rates [L/min] of rat-Lung
Q(9)  = 0.278;  % Blood Flow Rates [L/min] of rat-Muscle
Q(10) = 0.058;  % Blood Flow Rates [L/min] of rat-Skin
Q(11) = 0.02;   % Blood Flow Rates [L/min] of rat-Spleen
Q([1:3 5:7 9:10]) = Q([1:3 5:7 9:10])./sum(Q([1:3 5:7 9:10]));
Q     = Q.*(0.235*(bw^0.75));

P = zeros(NrTissue,1);
switch drug
    case 'Dia'
        P(1)  = 12.09;  % Adipose:Plasma ratio
        P(2)  = 6.03;   % Bone:Plasma ratio
        P(3)  = 11.82;  % Brain:Plasma ratio
        P(4)  = 7.20;   % Gut:Plasma ratio
        P(5)  = 3.87;   % Heart:Plasma ratio
        P(6)  = 4.59;   % Kidney:Plasma ratio
        P(7)  = 4.99;   % Liver:Plasma ratio
        P(8)  = 5.62;   % Lung:Plasma ratio
        P(9)  = 2.89;   % Muscle:Plasma ratio
        P(10) = 6.32;   % Skin:Plasma ratio
        P(11) = 2.65;   % Spleen:Plasma ratio
        P(12) = 0.0;    %
        P(13) = 0.0;    %
        P(14) = 0.851;  % Sink:Plasma ratio
        BP    = 1.04;   % Blood:Plasma ratio
        dose  = 1.2*bw; % [mg] Diazepam
    case 'Eth'
        P(1)  = 0.61;   % Adipose:Plasma ratio
        P(2)  = 0.53;   % Bone:Plasma ratio
        P(3)  = 0.99;   % Brain:Plasma ratio
        P(4)  = 0.82;   % Gut:Plasma ratio
        P(5)  = 0.77;   % Heart:Plasma ratio
        P(6)  = 0.79;   % Kidney:Plasma ratio
        P(7)  = 0.74;   % Liver:Plasma ratio
        P(8)  = 0.82;   % Lung:Plasma ratio
        P(9)  = 0.72;   % Muscle:Plasma ratio
        P(10) = 0.72;   % Skin:Plasma ratio
        P(11) = 0.73;   % Spleen:Plasma ratio
        P(12) = 0.0;    %
        P(13) = 0.0;    %
        P(14) = 0.082;  % Sink:Plasma ratio
        BP    = 1;      % Blood:Plasma ratio
        dose  = 20*bw;  % [mg] Ethoxybenzamide
    case 'Pro'
        P(1)  = 0.18;   % Adipose:Plasma ratio
        P(2)  = 6.90;   % Bone:Plasma ratio
        P(3)  = 13.54;  % Brain:Plasma ratio
        P(4)  = 8.22;   % Gut:Plasma ratio
        P(5)  = 4.38;   % Heart:Plasma ratio
        P(6)  = 5.18;   % Kidney:Plasma ratio
        P(7)  = 5.67;   % Liver:Plasma ratio
        P(8)  = 6.46;   % Lung:Plasma ratio
        P(9)  = 3.20;   % Muscle:Plasma ratio
        P(10) = 7.22;   % Skin:Plasma ratio
        P(11) = 2.98;   % Spleen:Plasma ratio
        P(12) = 0.0;    %
        P(13) = 0.0;    %
        P(14) = 0.985;  % Sink:Plasma ratio
        BP    = 0.8;    % Blood:Plasma ratio
        dose  = 1.5*bw; % [mg] Propranolol
end

X0=zeros(NrTissue,1);
X0(13) = dose;
x0     = X0./V;

% accuracy of ODE solver
RTol = 1e-4; %relative tolerance
ATol = 1e-6; % absolute tolerance



%% Definition of model reactions (only constant constituents)

% Model reactions
% X1  = adipose;        X2  = bone;     X3 = brain;     X4 = gut;   
% X5 = heart;           X6  = kidney;   X7  = liver;    X8 = lung;
% X9 = muscle;          X10 = skin;     X11 = spleen;   X12 = aterial blood;
% X13 = venous blood;   X14 = sink

global NrReactions
NrReactions = 25;

% Stoichiometric Matrix 
global S
S = zeros(NrTissue,NrReactions); 
%%%non-eliminating tissue (X1, X2, X3, X5, X6, X9, X10):%%%
%           X1  X2  X3  X4  X5  X6  X7  X8  X9 X10 X11 X12 X13 X14 
S(:,1)  = [ 1;  0;  0;  0;  0;  0;  0;  0;  0;  0;  0; -1;  0;  0;]; %r1:  X12 -> X1;  rate: Qad
S(:,2)  = [-1;  0;  0;  0;  0;  0;  0;  0;  0;  0;  0;  0;  1;  0;]; %r2:  X1  -> X13; rate: B:P*Qad/P(AD:P)
S(:,3)  = [ 0;  1;  0;  0;  0;  0;  0;  0;  0;  0;  0; -1;  0;  0;]; %r3:  X12 -> X2;  rate: Qbo
S(:,4)  = [ 0; -1;  0;  0;  0;  0;  0;  0;  0;  0;  0;  0;  1;  0;]; %r4:  X2  -> X13; rate: B:P*Qbo/P(BO:P)
S(:,5)  = [ 0;  0;  1;  0;  0;  0;  0;  0;  0;  0;  0; -1;  0;  0;]; %r5:  X12 -> X3;  rate: Qbr
S(:,6)  = [ 0;  0; -1;  0;  0;  0;  0;  0;  0;  0;  0;  0;  1;  0;]; %r6:  X3  -> X13; rate: B:P*Qbr/P(BR:P)
S(:,7)  = [ 0;  0;  0;  0;  1;  0;  0;  0;  0;  0;  0; -1;  0;  0;]; %r7:  X12 -> X5;  rate: Qhe
S(:,8)  = [ 0;  0;  0;  0; -1;  0;  0;  0;  0;  0;  0;  0;  1;  0;]; %r8:  X5  -> X13; rate: B:P*Qhe/P(HE:P)
S(:,9)  = [ 0;  0;  0;  0;  0;  1;  0;  0;  0;  0;  0; -1;  0;  0;]; %r9:  X12 -> X6;  rate: Qki
S(:,10) = [ 0;  0;  0;  0;  0; -1;  0;  0;  0;  0;  0;  0;  1;  0;]; %r10: X6  -> X13; rate: B:P*Qki/P(KI:P)
S(:,11) = [ 0;  0;  0;  0;  0;  0;  0;  0;  1;  0;  0; -1;  0;  0;]; %r11: X12 -> X9;  rate: Qmu
S(:,12) = [ 0;  0;  0;  0;  0;  0;  0;  0; -1;  0;  0;  0;  1;  0;]; %r12: X9  -> X13; rate: B:P*Qmu/P(MU:P)
S(:,13) = [ 0;  0;  0;  0;  0;  0;  0;  0;  0;  1;  0; -1;  0;  0;]; %r13: X12 -> X10; rate: Qsk
S(:,14) = [ 0;  0;  0;  0;  0;  0;  0;  0;  0; -1;  0;  0;  1;  0;]; %r14: X10 -> X13; rate: B:P*Qsk/P(SK:P)
%%%eliminating tissue(Liver/Hepatic):%%%
%           X1  X2  X3  X4  X5  X6  X7  X8  X9 X10 X11 X12 X13 X14 
S(:,15) = [ 0;  0;  0;  0;  0;  0;  1;  0;  0;  0;  0; -1;  0;  0;]; %r15: X12 -> X7;  rate: Qli-Qgu-Qsp
S(:,16) = [ 0;  0;  0;  0;  0;  0;  -1;  0;  0;  0;  0; 0;  0;  1;]; %r16: X12 -> X14; rate: E*(Qli-Qgu-Qsp)
S(:,17) = [ 0;  0;  0; -1;  0;  0;  1;  0;  0;  0;  0;  0;  0;  0;]; %r17: X4  -> X7;  rate: B:P*Qgu/P(GU:P)
S(:,18) = [ 0;  0;  0; 0;  0;  0;  -1;  0;  0;  0;  0;  0;  0;  1;]; %r18: X4  -> X14; rate: E*B:P*Qgu/P(GU:P)
S(:,19) = [ 0;  0;  0;  0;  0;  0;  1;  0;  0;  0; -1;  0;  0;  0;]; %r19: X11 -> X7;  rate: B:P*Qsp/P(SP:P)
S(:,20) = [ 0;  0;  0;  0;  0;  0;  -1;  0;  0;  0; 0;  0;  0;  1;]; %r20: X11 -> X14; rate: E*B:P*Qsp/P(SP:P)
S(:,21) = [ 0;  0;  0;  0;  0;  0; -1;  0;  0;  0;  0;  0;  1;  0;]; %r21: X7  -> X13; rate: B:P*Qli/P(LI:P)
%%%Lung:%%%
%           X1  X2  X3  X4  X5  X6  X7  X8  X9 X10 X11 X12 X13 X14 
S(:,22) = [ 0;  0;  0;  0;  0;  0;  0;  1;  0;  0;  0;  0; -1;  0;]; %r22: X13 -> X8;  rate: Qc
S(:,23) = [ 0;  0;  0;  0;  0;  0;  0; -1;  0;  0;  0;  1;  0;  0;]; %r23: X8  -> X12; rate: B:P*Qlu/P(LU:P)
%%%gut and spleen:%%%
%           X1  X2  X3  X4  X5  X6  X7  X8  X9 X10 X11 X12 X13 X14 
S(:,24) = [ 0;  0;  0;  1;  0;  0;  0;  0;  0;  0;  0; -1;  0;  0;]; %r24: X12 -> X4;  rate: Qgu
S(:,25) = [ 0;  0;  0;  0;  0;  0;  0;  0;  0;  0;  1; -1;  0;  0;]; %r25: X12 -> X11; rate: Qsl

% reaction parameters 
global k
k = ones(NrReactions,1);
k(1)  = Q(1);                       %rate r1:  Q(AD)
k(2)  = BP*Q(1)/P(1);               %rate r2:  B:P*Q(AD)/P(AD:P)
k(3)  = Q(2);                       %rate r3:  Q(BO)
k(4)  = BP*Q(2)/P(2);               %rate r4:  B:P*Q(BO)/P(BO:P)
k(5)  = Q(3);                       %rate r5:  Q(BR)
k(6)  = BP*Q(3)/P(3);               %rate r6:  B:P*Q(BR)/P(BR:P)
k(7)  = Q(5);                       %rate r7:  Q(HE)
k(8)  = BP*Q(5)/P(5);               %rate r8:  B:P*Q(HE)/P(HE:P)
k(9)  = Q(6);                       %rate r9:  Q(KI)
k(10) = BP*Q(6)/P(6);               %rate r10: B:P*Q(KI)/P(KI:P)
k(11) = Q(9);                       %rate r11: Q(MU)
k(12) = BP*Q(9)/P(9);               %rate r12: B:P*Q(MU)/P(MU:P)
k(13) = Q(10);                      %rate r13: Q(SK)
k(14) = BP*Q(10)/P(10);             %rate r14: B:P*Q(SK)/P(SK:P)
k(15) = Q(7)-Q(4)-Q(11);            %rate r15: Q(LI)-Q(GU)-Q(SP)
k(16) = P(14)*(Q(7)-Q(4)-Q(11));    %rate r16: E*(Q(LI)-Q(GU)-Q(SP))
k(17) = BP*Q(4)/P(4);               %rate r17: B:P*Q(GU)/P(GU:P)
k(18) = P(14)*BP*Q(4)/P(4);         %rate r18: E*B:P*Q(GU)/P(GU:P)
k(19) = BP*Q(11)/P(11);             %rate r19: B:P*Q(SP)/P(SP:P)
k(20) = P(14)*BP*Q(11)/P(11);       %rate r20: E*B:P*Q(SP)/P(SP:P)
k(21) = BP*Q(7)/P(7);               %rate r21: B:P*Q(LI)*/P(LI:P)
k(22) = Q(5);                       %rate r22: Q(HE)
k(23) = BP*Q(8)/P(8);               %rate r23: B:P*Q(LU)/P(LU:P)
k(24) = Q(4);                       %rate r24: Q(GU)
k(25) = Q(11);                      %rate r25: Q(SP)


%% Simulate
%settings of the ODE solver (mass balance equations, accuracy (relative, absolute))
options = odeset('Mass',diag(V),'RelTol',RTol,'AbsTol',ATol); 
[t,x] = ode15s(@RHSPK,[0 Simtime],x0,options);
